@@ -2,6 +2,10 @@
 """
 from .core import * # nolint
 
+# Hack for adrest loading in example project
+import sys
+sys.path.insert(0, op.abspath(op.dirname(op.dirname(op.dirname(__file__)))))
+
 
 ENVIRONMENT_NAME = 'production'
 
